@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2004-2006 Johan Svedberg <johan@svedberg.com>
+# Copyright (C) 2004-2007 Johan Svedberg <johan@svedberg.com>
 
 # This file is part of ontv.
 
@@ -22,6 +22,7 @@ import datetime
 import os.path
 import thread
 import urllib
+import sys
 from gettext import gettext as _
 
 import gtk
@@ -29,6 +30,7 @@ import gtk.gdk
 import gobject
 
 import GUI
+from ontv import IMAGES_DIR
 
 class Channel:
     def __init__(self, channel, xmltvfile):
@@ -78,10 +80,10 @@ class Channel:
         return None
 
     def __download_logo(self, icon, xmltvfile):
-        self.set_logo(GUI.logo_downloading_file)
-        gtk.threads_enter()
+        self.set_logo(os.path.join(IMAGES_DIR, "ontv-logo-downloading.png"))
+        gtk.gdk.threads_enter()
         xmltvfile.emit("downloading-logo", (self))
-        gtk.threads_leave()
+        gtk.gdk.threads_leave()
         config = xmltvfile.config
 
         if config.debug:
@@ -97,9 +99,9 @@ class Channel:
                                  ioe.strerror)
 
         self.set_logo(self.logo_file)
-        gtk.threads_enter()
+        gtk.gdk.threads_enter()
         xmltvfile.emit("downloading-logo-done", (self))
-        gtk.threads_leave()
+        gtk.gdk.threads_leave()
 
     def set_logo(self, file_name, silent=True):
         if os.path.exists(file_name):
