@@ -1,7 +1,7 @@
 NAME = 'OnTV'
-VERSION = '2.2.0'
+VERSION = '2.4.0'
 SERVERS_DIR = '/usr/local/lib/bonobo/servers'
 DATA_DIR = '/usr/local/share/ontv'
-PIXMAPS_DIR = '/usr/local/share/pixmaps'
+IMAGES_DIR = '/usr/local/share/ontv/images'
 UI_DIR = '/usr/local/share/gnome-2.0/ui'
 LOCALE_DIR = '/usr/local/share/locale'
